@@ -1,7 +1,7 @@
 from pkg_resources import get_distribution, DistributionNotFound
 from pathlib import Path
 
-BASE = Path('~/.tinytoken')
+BASE = Path('~/.tinytoken').expanduser()
 
 try:
     dist_name = __name__
